==> consumer-center-api-1.0.7-20170103.082456-2-sources.jar: cn/com/duiba/consumer/center/api/dto/SignRecordDto.java <==
/**
 * Project Name:activity-center-api
 * File Name:ConsumerSignRecord.java
 * Package Name:cn.com.duiba.activity.center.api.dto.sign
 * Date:2016年11月4日下午7:03:34
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.consumer.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * ClassName:ConsumerSignRecord <br/>
 * Date:     2016年11月4日 下午7:03:34 <br/>
 * @author   liyang
 * @version  
 * @since    JDK 1.6
 * @see
 *
 */
public class SignRecordDto implements Serializable {

    /**
     * 这个类暴露出去并没有什么卵用
     * serialVersionUID:TODO(用一句话描述这个变量表示什么).
     * @since JDK 1.6
     */
    private static final long serialVersionUID = 7853431268629508736L;
    
    public static final int    TYPE_CONTINUE      = 0;                    // 联系
    public static final int    TYPE_CIRCLE        = 1;                    //周期
    
    private Long id;
    private Long appId;
    private Long consumerId;
    @Deprecated //signConfig中的appId是唯一键,直接用appId去关联就好了
    private Long signConfigId = 0L;
    private Integer signDay;
    private Date firstSignDay;
    private Date endSignDay;//原来是只记录到天,现在改为记录到秒
    private Integer signType;
    private Date gmtCreate;
    private Date gmtModified;

    private transient Boolean isFristSign;
    
    public Long getId() {
        return id;
    }
    
    public void setId(Long id) {
        this.id = id;
    }
    
    public Long getAppId() {
        return appId;
    }
    
    public void setAppId(Long appId) {
        this.appId = appId;
    }
    
    public Long getConsumerId() {
        return consumerId;
    }
    
    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }
    @Deprecated
    public Long getSignConfigId() {
        return signConfigId;
    }
    @Deprecated
    public void setSignConfigId(Long signConfigId) {
        this.signConfigId = signConfigId;
    }
    
    public Integer getSignDay() {
        return signDay;
    }
    
    public void setSignDay(Integer signDay) {
        this.signDay = signDay;
    }
    
    public Date getFirstSignDay() {
        return firstSignDay;
    }
    
    public void setFirstSignDay(Date firstSignDay) {
        this.firstSignDay = firstSignDay;
    }
    
    public Date getEndSignDay() {
        return endSignDay;
    }
    
    public void setEndSignDay(Date endSignDay) {
        this.endSignDay = endSignDay;
    }
    
    public Integer getSignType() {
        return signType;
    }
    
    public void setSignType(Integer signType) {
        this.signType = signType;
    }
    
    public Date getGmtCreate() {
        return gmtCreate;
    }
    
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
    
    public Date getGmtModified() {
        return gmtModified;
    }
    
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
    
}

==> consumer-center-api-1.2.13-sources.jar: cn/com/duiba/consumer/center/api/dto/SignRecordDto.java <==
/**
 * Project Name:activity-center-api
 * File Name:ConsumerSignRecord.java
 * Package Name:cn.com.duiba.activity.center.api.dto.sign
 * Date:2016年11月4日下午7:03:34
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.consumer.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * ClassName:ConsumerSignRecord <br/>
 * Date:     2016年11月4日 下午7:03:34 <br/>
 * @author   liyang
 * @version  
 * @since    JDK 1.6
 * @see
 *
 */
public class SignRecordDto implements Serializable {

    private static final long serialVersionUID = 7853431268629508736L;
    
    public static final int    TYPE_CONTINUE      = 0;                    // 联系
    public static final int    TYPE_CIRCLE        = 1;                    //周期
    
    private Long id;
    private Long appId;
    private Long consumerId;
    /**
     * @deprecated (when, why, refactoring advice...)
     */
    @Deprecated //signConfig中的appId是唯一键,直接用appId去关联就好了
    private Long signConfigId = 0L;
    private Integer signDay;
    private Date firstSignDay;
    private Date endSignDay;//原来是只记录到天,现在改为记录到秒
    private Integer signType;
    private Date gmtCreate;
    private Date gmtModified;


    public Long getId() {
        return id;
    }
    
    public void setId(Long id) {
        this.id = id;
    }
    
    public Long getAppId() {
        return appId;
    }
    
    public void setAppId(Long appId) {
        this.appId = appId;
    }
    
    public Long getConsumerId() {
        return consumerId;
    }
    
    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    /**
     * @deprecated (when, why, refactoring advice...)
     */
    @Deprecated
    public Long getSignConfigId() {
        return signConfigId;
    }

    /**
     * @deprecated (when, why, refactoring advice...)
     */
    @Deprecated
    public void setSignConfigId(Long signConfigId) {
        this.signConfigId = signConfigId;
    }
    
    public Integer getSignDay() {
        return signDay;
    }
    
    public void setSignDay(Integer signDay) {
        this.signDay = signDay;
    }
    
    public Date getFirstSignDay() {
        return firstSignDay;
    }
    
    public void setFirstSignDay(Date firstSignDay) {
        this.firstSignDay = firstSignDay;
    }
    
    public Date getEndSignDay() {
        return endSignDay;
    }
    
    public void setEndSignDay(Date endSignDay) {
        this.endSignDay = endSignDay;
    }
    
    public Integer getSignType() {
        return signType;
    }
    
    public void setSignType(Integer signType) {
        this.signType = signType;
    }
    
    public Date getGmtCreate() {
        return gmtCreate;
    }
    
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
    
    public Date getGmtModified() {
        return gmtModified;
    }
    
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
    
}
